@@ -708,14 +708,14 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int jul)
     DBufInit(&calRow);
     DBufInit(&pre_buf);
     if (t->typ == RUN_TYPE && RunDisabled) return E_RUN_DISABLED;
-    if ((t->typ == PASSTHRU_TYPE && strcmp(t->passthru, "COLOR")) ||
+    if ((t->typ == PASSTHRU_TYPE && strcmp(t->passthru, "COLOR") && strcmp(t->passthru, "COLOUR")) ||
 	t->typ == CAL_TYPE ||
 	t->typ == PS_TYPE ||
 	t->typ == PSF_TYPE)
 	return OK;
 
     /* Handle COLOR types */
-    if (t->typ == PASSTHRU_TYPE && !strcmp(t->passthru, "COLOR")) {
+    if (t->typ == PASSTHRU_TYPE && (!strcmp(t->passthru, "COLOR") || !strcmp(t->passthru, "COLOUR"))) {
 	/* Strip off three tokens */
 	r = ParseToken(p, &buf);
 	if (!NextMode) {
@@ -924,7 +924,17 @@ int ShouldTriggerReminder(Trigger *t, TimeTrig *tim, int jul, int *err)
 
     /* Don't trigger timed reminders if DontIssueAts is true, and if the
        reminder is for today */
-    if (jul == JulianToday && DontIssueAts && tim->ttime != NO_TIME) return 0;
+    if (jul == JulianToday && DontIssueAts && tim->ttime != NO_TIME) {
+	if (DontIssueAts > 1) {
+	    /* If two or more -a options, then *DO* issue ats that are in the
+	       future */
+	    if (tim->ttime < SystemTime(0) / 60) {
+		return 0;
+	    }
+	} else {
+	    return 0;
+	}
+    }
 
     /* Don't trigger "old" timed reminders */
 /*** REMOVED...
