@@ -17,6 +17,7 @@
 #include <stdio.h>
 
 #include <string.h>
+#include <errno.h>
 #include <ctype.h>
 #include <sys/stat.h>
 
@@ -97,6 +98,32 @@ static void DestroyCache (CachedFile *cf);
 static int CheckSafety (void);
 static int PopFile (void);
 
+static void OpenPurgeFile(char const *fname, char const *mode)
+{
+    DynamicBuffer fname_buf;
+
+    if (PurgeFP != NULL && PurgeFP != stdout) {
+	fclose(PurgeFP);
+    }
+    PurgeFP = NULL;
+
+    /* Do not open a purge file if we're below purge
+       include depth */
+    if (IStackPtr-2 >= PurgeIncludeDepth) {
+	PurgeFP = NULL;
+	return;
+    }
+
+    DBufInit(&fname_buf);
+    if (DBufPuts(&fname_buf, fname) != OK) return;
+    if (DBufPuts(&fname_buf, ".purged") != OK) return;
+    PurgeFP = fopen(DBufValue(&fname_buf), mode);
+    if (!PurgeFP) {
+	fprintf(ErrFp, "Cannot open `%s' for writing: %s\n", DBufValue(&fname_buf), strerror(errno));
+    }
+    DBufFree(&fname_buf);
+}
+
 static void FreeChainItem(FilenameChain *chain)
 {
 	if (chain->filename) free((void *) chain->filename);
@@ -173,14 +200,32 @@ static int ReadLineFromFile(void)
 	}
 	if (feof(fp)) {
 	    FCLOSE(fp);
+	    if ((DBufLen(&buf) == 0) &&
+		(DBufLen(&LineBuffer) == 0) && PurgeMode) {
+		if (PurgeFP != NULL && PurgeFP != stdout) fclose(PurgeFP);
+		PurgeFP = NULL;
+	    }
 	}
 	l = DBufLen(&buf);
 	if (l && (DBufValue(&buf)[l-1] == '\\')) {
-	    DBufValue(&buf)[l-1] = '\n';
-	    if (DBufPuts(&LineBuffer, DBufValue(&buf)) != OK) {
-		DBufFree(&buf);
-		DBufFree(&LineBuffer);
-		return E_NO_MEM;
+	    if (PurgeMode) {
+		if (DBufPuts(&LineBuffer, DBufValue(&buf)) != OK) {
+		    DBufFree(&buf);
+		    DBufFree(&LineBuffer);
+		    return E_NO_MEM;
+		}
+		if (DBufPutc(&LineBuffer, '\n') != OK) {
+		    DBufFree(&buf);
+		    DBufFree(&LineBuffer);
+		    return E_NO_MEM;
+		}
+	    } else {
+		DBufValue(&buf)[l-1] = '\n';
+		if (DBufPuts(&LineBuffer, DBufValue(&buf)) != OK) {
+		    DBufFree(&buf);
+		    DBufFree(&LineBuffer);
+		    return E_NO_MEM;
+		}
 	    }
 	    continue;
 	}
@@ -212,6 +257,13 @@ int OpenFile(char const *fname)
     CachedFile *h = CachedFiles;
     int r;
 
+    if (PurgeMode) {
+	if (PurgeFP != NULL && PurgeFP != stdout) {
+	    fclose(PurgeFP);
+	}
+	PurgeFP = NULL;
+    }
+
 /* Assume we own the file for now */
     RunDisabled &= ~RUN_NOTOWNER;
 
@@ -236,6 +288,9 @@ int OpenFile(char const *fname)
 /* If it's a dash, then it's stdin */
     if (!strcmp(fname, "-")) {
 	fp = stdin;
+	if (PurgeMode) {
+	    PurgeFP = stdout;
+	}
 	if (DebugFlag & DB_TRACE_FILES) {
 	    fprintf(ErrFp, "Reading `-': Reading stdin\n");
 	}
@@ -244,6 +299,9 @@ int OpenFile(char const *fname)
 	if (DebugFlag & DB_TRACE_FILES) {
 	    fprintf(ErrFp, "Reading `%s': Opening file on disk\n", fname);
 	}
+	if (PurgeMode) {
+	    OpenPurgeFile(fname, "w");
+	}
     }
     if (!fp || !CheckSafety()) return E_CANT_OPEN;
     CLine = NULL;
@@ -257,8 +315,10 @@ int OpenFile(char const *fname)
 	    if (strcmp(fname, "-")) {
 		fp = fopen(fname, "r");
 		if (!fp || !CheckSafety()) return E_CANT_OPEN;
+		if (PurgeMode) OpenPurgeFile(fname, "w");
 	    } else {
 		fp = stdin;
+		if (PurgeMode) PurgeFP = stdout;
 	    }
 	}
     }
@@ -289,7 +349,11 @@ static int CacheFile(char const *fname)
 /* Create a file header */
     cf = NEW(CachedFile);
     cf->cache = NULL;
-    if (!cf) { ShouldCache = 0; FCLOSE(fp); return E_NO_MEM; }
+    if (!cf) {
+	ShouldCache = 0;
+	FCLOSE(fp);
+	return E_NO_MEM;
+    }
     cf->filename = StrDup(fname);
     if (!cf->filename) {
 	ShouldCache = 0;
@@ -315,7 +379,7 @@ static int CacheFile(char const *fname)
 	}
 /* Skip blank chars */
 	s = DBufValue(&LineBuffer);
-	while (isspace(*s)) s++;
+	while (isempty(*s)) s++;
 	if (*s && *s!=';' && *s!='#') {
 /* Add the line to the cache */
 	    if (!cl) {
@@ -424,8 +488,10 @@ static int PopFile(void)
 	if (strcmp(i->filename, "-")) {
 	    fp = fopen(i->filename, "r");
 	    if (!fp || !CheckSafety()) return E_CANT_OPEN;
+	    if (PurgeMode) OpenPurgeFile(i->filename, "a");
 	} else {
 	    fp = stdin;
+	    if (PurgeMode) PurgeFP = stdout;
 	}
 	if (fp != stdin)
 	    (void) fseek(fp, i->offset, 0);  /* Trust that it works... */
@@ -495,6 +561,10 @@ static int SetupGlobChain(char const *dirname, IncludeStruct *i)
     /* Check the cache */
     while(dc) {
 	if (!strcmp(dc->dirname, dir)) {
+	    if (DebugFlag & DB_TRACE_FILES) {
+		fprintf(ErrFp, "Found cached directory listing for `%s'\n",
+			dir);
+	    }
 	    free(dir);
 	    i->chain = dc->chain;
 	    return OK;
@@ -502,6 +572,10 @@ static int SetupGlobChain(char const *dirname, IncludeStruct *i)
 	dc = dc->next;
     }
 
+    if (DebugFlag & DB_TRACE_FILES) {
+	fprintf(ErrFp, "Scanning directory `%s' for *.rem files\n", dir);
+    }
+
     if (ShouldCache) {
 	dc = malloc(sizeof(DirectoryFilenameChain));
 	if (dc) {
@@ -512,6 +586,10 @@ static int SetupGlobChain(char const *dirname, IncludeStruct *i)
 	    }
 	}
 	if (dc) {
+	    if (DebugFlag & DB_TRACE_FILES) {
+		fprintf(ErrFp, "Caching directory `%s' listing\n", dir);
+	    }
+
 	    dc->chain = NULL;
 	    dc->next = CachedDirectoryChains;
 	    CachedDirectoryChains = dc;
@@ -615,9 +693,6 @@ int IncludeFile(char const *fname)
     if (stat(fname, &statbuf) == 0) {
 	FilenameChain *fc;
 	if (S_ISDIR(statbuf.st_mode)) {
-	    if (DebugFlag & DB_TRACE_FILES) {
-		fprintf(ErrFp, "Scanning directory `%s' for *.rem files\n", fname);
-	    }
 	    if (SetupGlobChain(fname, i) == OK) { /* Glob succeeded */
 		if (!i->chain) { /* Oops... no matching files */
 		    if (!Hush) {
@@ -723,7 +798,7 @@ static void DestroyCache(CachedFile *cf)
 /***************************************************************/
 int TopLevel(void)
 {
-    return !IStackPtr;
+    return IStackPtr <= 1;
 }
 
 /***************************************************************/
