@@ -1791,7 +1791,7 @@ static int FEasterdate(func_info *info)
 /*                                                             */
 /*  FIsdst and FMinsfromutc                                    */
 /*                                                             */
-/*  Check whether daylight savings time is in effect, and      */
+/*  Check whether daylight saving time is in effect, and      */
 /*  get minutes from UTC.                                      */
 /*                                                             */
 /***************************************************************/
@@ -1855,12 +1855,9 @@ static int FTimeStuff(int wantmins, func_info *info)
 static int SunStuff(int rise, double cosz, int jul)
 {
     int mins, hours;
-    int dusk_or_dawn;
     int year, mon, day;
-    int jan0;
-    double jan0d;
 
-    double M, L, tanA, sinDelta, cosDelta, a, a_hr, cosH, t, H, T;
+    double M, L, sinDelta, cosDelta, a, a_hr, cosH, t, H, T;
     double latitude, longdeg, UT, local;
 
 /* Get offset from UTC */
@@ -1880,10 +1877,7 @@ static int SunStuff(int rise, double cosz, int jul)
 
 
     FromJulian(jul, &year, &mon, &day);
-    jan0 = jul - Julian(year, 0, 1);
-    jan0d = (double) jan0;
 
-    dusk_or_dawn = rise;
     if (rise > 1)
 	rise -= 2;
 
@@ -1891,10 +1885,8 @@ static int SunStuff(int rise, double cosz, int jul)
     t = (double) jul;
     if (rise) {
 	t += (6.0 + longdeg/15.0) / 24.0;
-	jan0d += (6.0 + longdeg/15.0) / 24.0;
     } else {
 	t += (18.0 + longdeg/15.0) / 24.0;
-	jan0d += (18.0 + longdeg/15.0) / 24.0;
     }
 
 /* Mean anomaly of sun starting from 1 Jan 1990 */
@@ -1902,34 +1894,22 @@ static int SunStuff(int rise, double cosz, int jul)
 #if BASE != 1990
 #error Sun calculations assume a BASE of 1990!
 #endif
-    M = (0.9856002585 * t) + 357.828757;  /* In degrees */
+    t = 0.9856002585 * t;
+    M = t + 357.828757; /* In degrees */
 
     /* Make sure M is in the range [0, 360) */
     M -= (floor(M/360.0) * 360.0);
 
 /* Sun's true longitude */
-    L = M + 1.916*sin(DEGRAD*M) + 0.02*sin(2*DEGRAD*M) + 282.565;
+    L = M + 1.916*sin(DEGRAD*M) + 0.02*sin(2*DEGRAD*M) + 283.07080214;
     if (L > 360.0) L -= 360.0;
 
 /* Tan of sun's right ascension */
-    tanA = 0.91746 * tan(DEGRAD*L);
-    a = RADDEG * atan(tanA);
-
-/* Move a into same quadrant as L */
-    if (0.0 <= L && L < 90.0) {
-	if (a < 0.0) a += 180.0;
-    } else if (90.0 <= L && L < 180.0) {
-	a += 180.0;
-    } else if (180.0 <= L && L < 270.0) {
-	a += 180.0;
-    } else {
-	if (a > 0.0) a += 180.0;
+    a = RADDEG * atan2(0.91746*sin(DEGRAD*L), cos(DEGRAD*L));
+    if (a<0) {
+	a += 360.0;
     }
-/*   if (fabs(a - L) > 90.0)
-     a += 180.0; */
-    
-    if (a > 360.0)
-	a -= 360.0;
+
     a_hr = a / 15.0;
 
 /* Sine of sun's declination */
@@ -1951,7 +1931,9 @@ static int SunStuff(int rise, double cosz, int jul)
     H = RADDEG * acos(cosH);
     if (rise) H = 360.0 - H;
 
-    T = H / 15.0 + a_hr - 0.065710 * jan0d - 6.620;
+    t -= 360.0*floor(t/360.0);
+    T = (H-t) / 15.0 + a_hr - 6.726637276;
+
     if (T >= 24.0) T -= 24.0;
     else if (T < 0.0) T+= 24.0;
     
