@@ -12,8 +12,6 @@
 /*                                                             */
 /***************************************************************/
 
-/* $Id: italian.h,v 1.6 2000/02/18 03:46:23 dfs Exp $ */
-
 /* The very first define in a language support file must be L_LANGNAME: */
 #define L_LANGNAME "Italian"
 
@@ -108,23 +106,23 @@
 		    		MonthName[m], y);	
 #define L_C_OVER	sprintf(s, "%s", DayName[jul%7]);	
 
-#define L_E_OVER	sprintf(s, "%02d%c%02d%c%04d", d, DATESEP,\
-				 m+1, DATESEP, y);	
+#define L_E_OVER	sprintf(s, "%02d%c%02d%c%04d", d, DateSep,\
+				 m+1, DateSep, y);	
 
-#define L_F_OVER	sprintf(s, "%02d%c%02d%c%04d", m+1, DATESEP, d, DATESEP, y);	
+#define L_F_OVER	sprintf(s, "%02d%c%02d%c%04d", m+1, DateSep, d, DateSep, y);	
 
 #define L_G_OVER	sprintf(s, "%s, %d %s", DayName[jul%7], d, MonthName[m]);	
 
-#define L_H_OVER	sprintf(s, "%02d%c%02d", d, DATESEP, m+1);	
+#define L_H_OVER	sprintf(s, "%02d%c%02d", d, DateSep, m+1);	
 
-#define L_I_OVER	sprintf(s, "%02d%c%02d", m+1, DATESEP, d);	
+#define L_I_OVER	sprintf(s, "%02d%c%02d", m+1, DateSep, d);	
 
 #define L_J_OVER	sprintf(s, "%s, %d %s %d", DayName[jul%7], d, \
 				MonthName[m], y);
 
 #define L_K_OVER	sprintf(s, "%s, %d %s", DayName[jul%7], d, \
 				MonthName[m]);
-#define L_L_OVER	sprintf(s, "%04d%c%02d%c%02d", y, DATESEP, m+1, DATESEP, d);	
+#define L_L_OVER	sprintf(s, "%04d%c%02d%c%02d", y, DateSep, m+1, DateSep, d);	
 
 #define L_U_OVER	sprintf(s, "%s, %d %s %d", DayName[jul%7], d, \
 				MonthName[m], y);
