@@ -94,6 +94,7 @@ Token TokArray[] = {
     { "special",        7,      T_RemType,      PASSTHRU_TYPE },
     { "sunday",		3,	T_WkDay,	6 },
     { "tag",            3,      T_Tag,          0 },
+    { "through",        7,      T_Through,      0 },
     { "thursday",	3,	T_WkDay,	3 },
     { "tuesday",	3,	T_WkDay,	1 },
     { "unset",		5,	T_UnSet,	0 },
@@ -359,7 +360,7 @@ static int TokStrCmp(Token const *t, char const *s)
     register int r;
     char const *tk = t->name;
     while(*tk && *s && !(*s == ',' && *(s+1) == 0)) {
-	r = *tk - tolower(*s);
+	r = tolower(*tk) - tolower(*s);
 	tk++;
 	s++;
 	if (r) return r;
@@ -367,5 +368,5 @@ static int TokStrCmp(Token const *t, char const *s)
     /* Ignore trailing commas on s */
 
     if (!*s || (*s == ',' && !*(s+1))) return 0;
-    return (*tk - *s);
+    return (tolower(*tk) - tolower(*s));
 }
