@@ -426,7 +426,9 @@ int ComputeTrigger(int today, Trigger *trig, int *err, int save_in_globals)
 	result;
 
     trig->expired = 0;
-    if (save_in_globals) LastTrigValid = 0;
+    if (save_in_globals) {
+	LastTrigValid = 0;
+    }
 
 /* Assume everything works */
     *err = OK;
