@@ -73,7 +73,7 @@ typedef struct {
     char sched[VAR_NAME_LEN+1];  /* Scheduling function */
     char warn[VAR_NAME_LEN+1];   /* Warning function    */
     char omitfunc[VAR_NAME_LEN+1]; /* OMITFUNC function */
-    char tag[TAG_LEN+1];
+    DynamicBuffer tags;
     char passthru[PASSTHRU_LEN+1];
 } Trigger;
 
@@ -167,7 +167,8 @@ enum TokTypes
   T_Tag,
   T_Duration,
   T_LongTime,
-  T_OmitFunc
+  T_OmitFunc,
+  T_Through
 };
 
 /* The structure of a token */
