@@ -36,6 +36,110 @@ static Var *VHashTbl[VAR_HASH_SIZE];
 
 typedef int (*SysVarFunc)(int, Value *);
 
+static int trig_date_func(int do_set, Value *val)
+{
+    val->type = DATE_TYPE;
+    if (!LastTrigValid) {
+	val->v.val = 0;
+    } else {
+	val->v.val = LastTriggerDate;
+    }
+    return OK;
+}
+static int trig_day_func(int do_set, Value *val)
+{
+    int y, m, d;
+    val->type = INT_TYPE;
+    if (!LastTrigValid) {
+	val->v.val = -1;
+	return OK;
+    }
+
+    FromJulian(LastTriggerDate, &y, &m, &d);
+    val->v.val = d;
+    return OK;
+}
+
+static int trig_mon_func(int do_set, Value *val)
+{
+    int y, m, d;
+    val->type = INT_TYPE;
+    if (!LastTrigValid) {
+	val->v.val = -1;
+	return OK;
+    }
+
+    FromJulian(LastTriggerDate, &y, &m, &d);
+    val->v.val = m+1;
+    return OK;
+}
+
+static int trig_year_func(int do_set, Value *val)
+{
+    int y, m, d;
+    val->type = INT_TYPE;
+    if (!LastTrigValid) {
+	val->v.val = -1;
+	return OK;
+    }
+
+    FromJulian(LastTriggerDate, &y, &m, &d);
+    val->v.val = y;
+    return OK;
+}
+
+static int trig_wday_func(int do_set, Value *val)
+{
+    val->type = INT_TYPE;
+    if (!LastTrigValid) {
+	val->v.val = -1;
+	return OK;
+    }
+
+    val->v.val = (LastTriggerDate + 1) % 7;
+    return OK;
+}
+
+static int today_date_func(int do_set, Value *val)
+{
+    val->type = DATE_TYPE;
+    val->v.val = JulianToday;
+    return OK;
+}
+static int today_day_func(int do_set, Value *val)
+{
+    int y, m, d;
+    val->type = INT_TYPE;
+    FromJulian(JulianToday, &y, &m, &d);
+    val->v.val = d;
+    return OK;
+}
+
+static int today_mon_func(int do_set, Value *val)
+{
+    int y, m, d;
+    val->type = INT_TYPE;
+    FromJulian(JulianToday, &y, &m, &d);
+    val->v.val = m+1;
+    return OK;
+}
+
+static int today_year_func(int do_set, Value *val)
+{
+    int y, m, d;
+    val->type = INT_TYPE;
+    FromJulian(JulianToday, &y, &m, &d);
+    val->v.val = y;
+    return OK;
+}
+
+static int today_wday_func(int do_set, Value *val)
+{
+    val->type = INT_TYPE;
+    val->v.val = (JulianToday + 1) % 7;
+    return OK;
+}
+
 static int date_sep_func(int do_set, Value *val)
 {
     if (!do_set) {
@@ -186,7 +290,7 @@ int SetVar(char const *str, Value *val)
 /*  Get a copy of the value of the variable.                   */
 /*                                                             */
 /***************************************************************/
-int GetVarValue(char const *str, Value *val, Var *locals)
+int GetVarValue(char const *str, Value *val, Var *locals, ParsePtr p)
 {
     Var *v;
 
@@ -198,6 +302,8 @@ int GetVarValue(char const *str, Value *val, Var *locals)
 	v = v->next;
     }
 
+    /* Global variable... mark expression as non-constant */
+    if (p) p->nonconst_expr = 1;
     v=FindVar(str, 0);
 
     if (!v) {
@@ -223,7 +329,7 @@ int DoSet (Parser *p)
     r = ParseIdentifier(p, &buf);
     if (r) return r;
 
-    /* Allow option equals-sign:  SET var = value */
+    /* Allow optional equals-sign:  SET var = value */
     if (ParseNonSpaceChar(p, &r, 1) == '=') {
 	ParseNonSpaceChar(p, &r, 0);
     }
@@ -286,6 +392,8 @@ int DoDump(ParsePtr p)
     Var *v;
     DynamicBuffer buf;
 
+    if (PurgeMode) return OK;
+
     DBufInit(&buf);
     r = ParseToken(p, &buf);
     if (r) return r;
@@ -462,45 +570,57 @@ typedef struct {
 
 /* All of the system variables sorted alphabetically */
 static SysVar SysVarArr[] = {
-    /* name		  mod	type		value		min/mal	max */
-    {   "CalcUTC",	  1,	INT_TYPE,	&CalculateUTC,	0,	1   },
-    {   "CalMode",	  0,	INT_TYPE,	&DoCalendar,	0,	0   },
-    {   "Daemon",	  0,	INT_TYPE,	&Daemon,	0,	0   },
-    {   "DateSep",        1,    SPECIAL_TYPE,   date_sep_func,  0,      0   },
-    {   "DefaultPrio",	  1,	INT_TYPE,	&DefaultPrio,	0,	9999 },
-    {   "DeltaOffset",    0,    INT_TYPE,       &DeltaOffset,   0,      0   },
-    {   "DontFork",	  0,	INT_TYPE,	&DontFork,	0,	0   },
-    {   "DontQueue",	  0,	INT_TYPE,	&DontQueue,	0,	0   },
-    {   "DontTrigAts",	  0,	INT_TYPE,	&DontIssueAts,	0,	0   },
-    {   "EndSent",	  1,	STR_TYPE,	&EndSent,	0,	0   },
-    {   "EndSentIg",	  1,	STR_TYPE,	&EndSentIg,	0,	0   },
-    {   "FirstIndent",	  1,	INT_TYPE,	&FirstIndent,	0,	132 },
-    {   "FoldYear",	  1,	INT_TYPE,	&FoldYear,	0,	1   },
-    {   "FormWidth",	  1,	INT_TYPE,	&FormWidth,	20,	132 },
-    {   "HushMode",	  0,	INT_TYPE,	&Hush,		0,	0   },
-    {   "IgnoreOnce",	  0,	INT_TYPE,	&IgnoreOnce,	0,	0   },
-    {   "InfDelta",	  0,	INT_TYPE,	&InfiniteDelta,	0,	0   },
-    {   "LatDeg",	  1,	INT_TYPE,	&LatDeg,	-90,	90  },
-    {   "LatMin",	  1,	INT_TYPE,	&LatMin,	-59,	59  },
-    {   "LatSec",	  1,	INT_TYPE,	&LatSec,	-59,	59  },
-    {   "Location",	  1,	STR_TYPE,	&Location,	0,	0   },
-    {   "LongDeg",	  1,	INT_TYPE,	&LongDeg,	-180,	180  },
-    {   "LongMin",	  1,	INT_TYPE,	&LongMin,	-59,	59  },
-    {   "LongSec",	  1,	INT_TYPE,	&LongSec,	-59,	59  },
-    {   "MaxSatIter",	  1,	INT_TYPE,	&MaxSatIter,	10,	ANY },
-    {   "MinsFromUTC",	  1,	INT_TYPE,	&MinsFromUTC,	-13*60,	13*60 },
-    {   "NextMode",	  0,	INT_TYPE,	&NextMode,	0,	0   },
-    {   "NumQueued",	  0,	INT_TYPE,	&NumQueued,	0,	0   },
-    {   "NumTrig",	  0,	INT_TYPE,	&NumTriggered,	0,	0   },
-    {   "PrefixLineNo",	  0,	INT_TYPE,	&DoPrefixLineNo,0,	0   },
-    {   "PSCal",	  0,	INT_TYPE,	&PsCal,		0,	0   },
-    {   "RunOff",	  0,	INT_TYPE,	&RunDisabled,	0,	0   },
-    {   "SimpleCal",	  0,	INT_TYPE,	&DoSimpleCalendar,	0,  0 },
-    {   "SortByDate",	  0,	INT_TYPE,	&SortByDate,	0,	0},
-    {   "SortByPrio",	  0,	INT_TYPE,	&SortByPrio,	0,	0},
-    {   "SortByTime",	  0,	INT_TYPE,	&SortByTime,	0,	0},
-    {   "SubsIndent",	  1,	INT_TYPE,	&SubsIndent,	0,	132},
-    {   "TimeSep",        1,    SPECIAL_TYPE,   time_sep_func,  0,      0   }
+    /*  name          mod  type              value         min/mal   max */
+    {"CalcUTC",        1,  INT_TYPE,     &CalculateUTC,       0,      1   },
+    {"CalMode",        0,  INT_TYPE,     &DoCalendar,         0,      0   },
+    {"Daemon",         0,  INT_TYPE,     &Daemon,             0,      0   },
+    {"DateSep",        1,  SPECIAL_TYPE, date_sep_func,       0,      0   },
+    {"DefaultPrio",    1,  INT_TYPE,     &DefaultPrio,        0,      9999},
+    {"DeltaOffset",    0,  INT_TYPE,     &DeltaOffset,        0,      0   },
+    {"DontFork",       0,  INT_TYPE,     &DontFork,           0,      0   },
+    {"DontQueue",      0,  INT_TYPE,     &DontQueue,          0,      0   },
+    {"DontTrigAts",    0,  INT_TYPE,     &DontIssueAts,       0,      0   },
+    {"EndSent",        1,  STR_TYPE,     &EndSent,            0,      0   },
+    {"EndSentIg",      1,  STR_TYPE,     &EndSentIg,          0,      0   },
+    {"FirstIndent",    1,  INT_TYPE,     &FirstIndent,        0,      132 },
+    {"FoldYear",       1,  INT_TYPE,     &FoldYear,           0,      1   },
+    {"FormWidth",      1,  INT_TYPE,     &FormWidth,          20,     132 },
+    {"HushMode",       0,  INT_TYPE,     &Hush,               0,      0   },
+    {"IgnoreOnce",     0,  INT_TYPE,     &IgnoreOnce,         0,      0   },
+    {"InfDelta",       0,  INT_TYPE,     &InfiniteDelta,      0,      0   },
+    {"LatDeg",         1,  INT_TYPE,     &LatDeg,             -90,    90  },
+    {"LatMin",         1,  INT_TYPE,     &LatMin,             -59,    59  },
+    {"LatSec",         1,  INT_TYPE,     &LatSec,             -59,    59  },
+    {"Location",       1,  STR_TYPE,     &Location,           0,      0   },
+    {"LongDeg",        1,  INT_TYPE,     &LongDeg,            -180,   180 },
+    {"LongMin",        1,  INT_TYPE,     &LongMin,            -59,    59  },
+    {"LongSec",        1,  INT_TYPE,     &LongSec,            -59,    59  },
+    {"MaxSatIter",     1,  INT_TYPE,     &MaxSatIter,         10,     ANY },
+    {"MaxStringLen",   1,  INT_TYPE,     &MaxStringLen,       -1,     ANY },
+    {"MinsFromUTC",    1,  INT_TYPE,     &MinsFromUTC,        -780,   780 },
+    {"NextMode",       0,  INT_TYPE,     &NextMode,           0,      0   },
+    {"NumQueued",      0,  INT_TYPE,     &NumQueued,          0,      0   },
+    {"NumTrig",        0,  INT_TYPE,     &NumTriggered,       0,      0   },
+    {"PrefixLineNo",   0,  INT_TYPE,     &DoPrefixLineNo,     0,      0   },
+    {"PSCal",          0,  INT_TYPE,     &PsCal,              0,      0   },
+    {"RunOff",         0,  INT_TYPE,     &RunDisabled,        0,      0   },
+    {"SimpleCal",      0,  INT_TYPE,     &DoSimpleCalendar,   0,      0   },
+    {"SortByDate",     0,  INT_TYPE,     &SortByDate,         0,      0   },
+    {"SortByPrio",     0,  INT_TYPE,     &SortByPrio,         0,      0   },
+    {"SortByTime",     0,  INT_TYPE,     &SortByTime,         0,      0   },
+    {"SubsIndent",     1,  INT_TYPE,     &SubsIndent,         0,      132 },
+    {"T",              0,  SPECIAL_TYPE, trig_date_func,      0,      0   },
+    {"Td",             0,  SPECIAL_TYPE, trig_day_func,       0,      0   },
+    {"TimeSep",        1,  SPECIAL_TYPE, time_sep_func,       0,      0   },
+    {"Tm",             0,  SPECIAL_TYPE, trig_mon_func,       0,      0   },
+    {"Tw",             0,  SPECIAL_TYPE, trig_wday_func,      0,      0   },
+    {"Ty",             0,  SPECIAL_TYPE, trig_year_func,      0,      0   },
+    {"U",              0,  SPECIAL_TYPE, today_date_func,     0,      0   },
+    {"Ud",             0,  SPECIAL_TYPE, today_day_func,      0,      0   },
+    {"Um",             0,  SPECIAL_TYPE, today_mon_func,      0,      0   },
+    {"UntimedFirst",   0,  INT_TYPE,     &UntimedBeforeTimed, 0,      0   },
+    {"Uw",             0,  SPECIAL_TYPE, today_wday_func,     0,      0   },
+    {"Uy",             0,  SPECIAL_TYPE, today_year_func,     0,      0   }
 };
 
 #define NUMSYSVARS ( sizeof(SysVarArr) / sizeof(SysVar) )
@@ -644,9 +764,8 @@ static void DumpSysVar(char const *name, const SysVar *v)
 	    Value val;
 	    SysVarFunc f = (SysVarFunc) v->value;
 	    f(0, &val);
-	    if (DoCoerce(STR_TYPE, &val) == OK) {
-		fprintf(ErrFp, "\"%s\"\n", val.v.str);
-	    }
+	    PrintValue(&val, ErrFp);
+	    Putc('\n', ErrFp);
 	    DestroyValue(val);
 	} else if (v->type == STR_TYPE) {
 	    char const *s = *((char **)v->value);
@@ -663,6 +782,12 @@ static void DumpSysVar(char const *name, const SysVar *v)
 	    Putc('"', ErrFp);
 	    if (*s) fprintf(ErrFp, "...");
 	    Putc('\n', ErrFp);
+	} else if (v->type == DATE_TYPE) {
+	    Value val;
+	    val.type = DATE_TYPE;
+	    val.v.val = * (int *) v->value;
+	    PrintValue(&val, ErrFp);
+	    Putc('\n', ErrFp);
 	} else {
 	    if (!v->modifiable) fprintf(ErrFp, "%d\n", *((int *)v->value));
 	    else {
